%define main_release 37
%define samba4_version 4.0.0

%define talloc_version 2.0.5
%define tdb_version 1.2.9
%define tevent_version 0.9.11
%define ldb_version 1.0.2

%define pre_release alpha16

%define tarball_name samba-%{samba4_version}%{pre_release}

%define samba4_release %{main_release}.%{pre_release}

# Most of these subpackages are disabled because they are not
# needed by OpenChange, and to avoid file conflicts with Samba3.
%define enable_samba4  0
%define enable_client  0
%define enable_common  0
%define enable_python  0
%define enable_winbind 0

%{!?python_libdir: %define python_libdir %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1,1)")}
%{!?python_sitearch: %define python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}

# Licensing Note: Some of the libraries are GPLv3+, others are LGPLv3+.
# The rest of the code is GPLv3+.  Library licensing is still volatile,
# and subject to change.

Name: samba4
Version: %{samba4_version}
Release: %{samba4_release}%{?dist}
Group: System Environment/Daemons
Summary: The Samba4 CIFS and AD client and server suite
License: GPLv3+ and LGPLv3+
URL: http://www.samba.org/
Source: http://download.samba.org/samba/ftp/samba4/%{tarball_name}.tar.gz
BuildRoot: %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

# Red Hat specific replacement-files
%if %enable_samba4
Source1: %{name}.log
Source4: %{name}.sysconfig
Source5: %{name}.init
%endif

Patch01: samba-4.0.0alpha16.buildfix.patch

Requires(pre): /usr/sbin/groupadd

%if %enable_samba4
Requires(post): /sbin/chkconfig, /sbin/service
Requires(preun): /sbin/chkconfig, /sbin/service
%endif

%if %enable_common
Requires(pre): %{name}-common = %{version}-%{release}
%endif

Requires: logrotate
Requires: pam
Requires: perl(Parse::Yapp)

BuildRequires: e2fsprogs-devel
BuildRequires: libacl-devel
BuildRequires: libaio-devel
BuildRequires: libattr-devel
BuildRequires: ncurses-devel
BuildRequires: pam-devel
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(Parse::Yapp)
BuildRequires: popt-devel
BuildRequires: python-devel
BuildRequires: readline-devel
BuildRequires: sed
BuildRequires: autoconf
BuildRequires: openldap-devel
BuildRequires: libxslt
BuildRequires: docbook-style-xsl
BuildRequires: pytalloc-devel

BuildRequires: libtalloc-devel >= %{talloc_version}
BuildRequires: pytalloc >= %{talloc_version}
BuildRequires: libtdb-devel >= %{tdb_version}
BuildRequires: libtevent-devel >= %{tevent_version}
BuildRequires: libldb-devel >= %{ldb_version}
BuildRequires: pyldb-devel >= %{ldb_version}

BuildRequires: zlib-devel >= 1.2.3

%description

Samba 4 is the ambitious next version of the Samba suite that is being
developed in parallel to the stable 3.0 series. The main emphasis in
this branch is support for the Active Directory logon protocols used
by Windows 2000 and above.

%if %enable_client
%package client
Summary: Samba client programs
Group: Applications/System
Requires: %{name}-common = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}

%description client
The %{name}-client package provides some SMB/CIFS clients to complement
the built-in SMB/CIFS filesystem in Linux. These clients allow access
of SMB/CIFS shares and printing to SMB/CIFS printers.
%endif

%package libs
Summary: Samba libraries
Group: Applications/System

%description libs
The %{name}-libs package contains the libraries needed by programs that
link against the SMB, RPC and other protocols provided by the Samba suite.

%if %enable_python
%package python
Summary: Samba Python libraries
Group: Applications/System
Requires: %{name}-libs = %{version}-%{release}

%description python
The %{name}-python package contains the Python libraries needed by programs
that use SMB, RPC and other Samba provided protocols in Python programs.
%endif

%package devel
Summary: Developer tools for Samba libraries
Group: Development/Libraries
Requires: %{name}-libs = %{version}-%{release}

%description devel
The %{name}-devel package contains the header files for the libraries
needed to develop programs that link against the SMB, RPC and other
libraries in the Samba suite.

%package pidl
Summary: Perl IDL compiler
Group: Development/Tools
Requires: perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))

%description pidl
The %{name}-pidl package contains the Perl IDL compiler used by Samba
and Wireshark to parse IDL and similar protocols

%if %enable_common
%package common
Summary: Files used by both Samba servers and clients
Group: Applications/System
Requires: %{name}-libs = %{version}-%{release}

%description common
%{Name}-common provides files necessary for both the server and client
packages of Samba.
%endif

%if %enable_winbind
%package winbind
Summary: Samba winbind
Group: Applications/System
Requires: %{name} = %{version}-%{release}

%description winbind
The samba-winbind package provides the winbind NSS library, and some
client tools.  Winbind enables Linux to be a full member in Windows
domains and to use Windows user and group accounts on Linux.
%endif

%prep
%setup -q -n %{tarball_name}

# copy Red Hat specific scripts
%patch01 -p1 -b .buildfix

%build
%configure \
        --with-modulesdir=%{_libdir}/samba \
	--with-lockdir=/var/lib/%{name} \
	--with-piddir=/var/run \
	--with-privatedir=/var/lib/%{name}/private \
        --with-sockets-dir=/var/run \
	--sysconfdir=%{_sysconfdir}/%{name} \
        --datadir=%{_datadir}/samba \
	--disable-gnutls \
	--disable-rpath-install \
	--builtin-libraries=ccan,wbclient \
	--bundled-libraries=heimdal,!talloc,!tdb,!tevent,!ldb,!zlib

# Build PIDL for installation into vendor directories before
# 'make proto' gets to it.
(cd pidl && %{__perl} Makefile.PL INSTALLDIRS=vendor )

# Builds using PIDL the IDL and many other things.
#make proto
#make everything
make -j

%install
rm -rf $RPM_BUILD_ROOT

# Don't call 'make install' as we want to call out to the PIDL
# install manually.
make install DESTDIR=$RPM_BUILD_ROOT

# Undo the PIDL install, we want to try again with the right options.
rm -rf $RPM_BUILD_ROOT%{_libdir}/perl5
rm -rf $RPM_BUILD_ROOT%{_datadir}/perl5

# Install PIDL.
( cd pidl && make install PERL_INSTALL_ROOT=$RPM_BUILD_ROOT )

# Clean out crap left behind by the PIDL install.
find $RPM_BUILD_ROOT -type f -name .packlist -exec rm -f {} \;
find $RPM_BUILD_ROOT -depth -type d -exec rmdir {} 2>/dev/null \;

%if %enable_samba4
mkdir -p $RPM_BUILD_ROOT%{_initrddir}
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig
%endif

mkdir -p $RPM_BUILD_ROOT/var/run/winbindd
mkdir -p $RPM_BUILD_ROOT/var/run/ntp_signd
mkdir -p $RPM_BUILD_ROOT/var/lib/%{name}/winbindd_privileged
mkdir -p $RPM_BUILD_ROOT/var/log/%{name}/
mkdir -p $RPM_BUILD_ROOT/var/log/%{name}/old

mkdir -p $RPM_BUILD_ROOT/var/lib/%{name}
mkdir -p $RPM_BUILD_ROOT/var/lib/%{name}/private
mkdir -p $RPM_BUILD_ROOT/var/lib/%{name}/sysvol

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/%{name}

%if %enable_samba4
# Install other stuff.
install -m755 %{SOURCE5} $RPM_BUILD_ROOT%{_initrddir}/%{name}
install -m644 %{SOURCE1} $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/%{name}
install -m644 %{SOURCE4} $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/%{name}
%endif

%if ! %enable_winbind
rm $RPM_BUILD_ROOT%{_bindir}/ntlm_auth
rm $RPM_BUILD_ROOT%{_bindir}/wbinfo
rm $RPM_BUILD_ROOT%{_libdir}/libnss_winbind.so.2
rm $RPM_BUILD_ROOT%{_libdir}/pam_winbind.so
#rm $RPM_BUILD_ROOT%{_libdir}/libwbclient.so
#rm $RPM_BUILD_ROOT%{_libdir}/libwbclient.so.*
rm $RPM_BUILD_ROOT%{_mandir}/man1/ntlm_auth.*
rm $RPM_BUILD_ROOT%{_includedir}/samba-4.0/wbclient.h
%endif

# Clean out some stuff we don't want in the Fedora package.
rm $RPM_BUILD_ROOT%{_bindir}/gentest
rm $RPM_BUILD_ROOT%{_mandir}/man1/gentest.*
rm $RPM_BUILD_ROOT%{_bindir}/locktest
rm $RPM_BUILD_ROOT%{_mandir}/man1/locktest.*
rm $RPM_BUILD_ROOT%{_bindir}/masktest
rm $RPM_BUILD_ROOT%{_mandir}/man1/masktest.*
rm $RPM_BUILD_ROOT%{_bindir}/ndrdump
rm $RPM_BUILD_ROOT%{_mandir}/man1/ndrdump.*
rm $RPM_BUILD_ROOT%{_bindir}/nsstest
rm $RPM_BUILD_ROOT%{_bindir}/smbtorture
rm $RPM_BUILD_ROOT%{_mandir}/man1/smbtorture.*
#depending on the environemnt this file might or might not be generated
rm -f $RPM_BUILD_ROOT%{_bindir}/tdbtorture

# Avoids a file conflict with perl-Parse-Yapp.
rm -rf $RPM_BUILD_ROOT%{perl_vendorlib}/Parse/Yapp

# Remove files for disabled subpackages.
%if ! %enable_samba4
rm $RPM_BUILD_ROOT%{_sbindir}/provision
rm $RPM_BUILD_ROOT%{_sbindir}/samba
rm $RPM_BUILD_ROOT%{_sbindir}/upgradeprovision
rm $RPM_BUILD_ROOT%{_sbindir}/samba_dnsupdate
rm $RPM_BUILD_ROOT%{_sbindir}/samba_spnupdate
rm $RPM_BUILD_ROOT%{_bindir}/samba-tool
rm $RPM_BUILD_ROOT%{_libdir}/mit_samba.so
rm $RPM_BUILD_ROOT%{_mandir}/man8/samba.*
rm -rf $RPM_BUILD_ROOT%{_datadir}/samba/setup
rm -rf $RPM_BUILD_ROOT%{_datadir}/samba/swat
%endif
%if ! %enable_client
rm $RPM_BUILD_ROOT%{_bindir}/nmblookup
rm $RPM_BUILD_ROOT%{_bindir}/smbclient
rm $RPM_BUILD_ROOT%{_bindir}/cifsdd
rm $RPM_BUILD_ROOT%{_mandir}/man1/nmblookup.*
%endif
%if ! %enable_common
rm $RPM_BUILD_ROOT%{_bindir}/regdiff
rm $RPM_BUILD_ROOT%{_bindir}/regpatch
rm $RPM_BUILD_ROOT%{_bindir}/regshell
rm $RPM_BUILD_ROOT%{_bindir}/regtree
rm $RPM_BUILD_ROOT%{_bindir}/testparm
rm $RPM_BUILD_ROOT%{_mandir}/man1/regdiff.*
rm $RPM_BUILD_ROOT%{_mandir}/man1/regpatch.*
rm $RPM_BUILD_ROOT%{_mandir}/man1/regshell.*
rm $RPM_BUILD_ROOT%{_mandir}/man1/regtree.*
%endif

# the samba4 build process rebuilds libraries internally,
# but we want to use the standalone build for now.
#rm $RPM_BUILD_ROOT%{_libdir}/libldb.so*
#rm $RPM_BUILD_ROOT%{_bindir}/ad2oLschema
#rm $RPM_BUILD_ROOT%{_bindir}/ldbadd
#rm $RPM_BUILD_ROOT%{_bindir}/ldbdel
#rm $RPM_BUILD_ROOT%{_bindir}/ldbedit
#rm $RPM_BUILD_ROOT%{_bindir}/ldbmodify
#rm $RPM_BUILD_ROOT%{_bindir}/ldbrename
#rm $RPM_BUILD_ROOT%{_bindir}/ldbsearch
rm $RPM_BUILD_ROOT%{_bindir}/oLschema2ldif
#rm -f $RPM_BUILD_ROOT%{_bindir}/tdbbackup
#rm -f $RPM_BUILD_ROOT%{_bindir}/tdbdump
#rm -f $RPM_BUILD_ROOT%{_bindir}/tdbtool


#rm -f $RPM_BUILD_ROOT%{_libdir}/lib*.a

%if ! %enable_python
rm -r $RPM_BUILD_ROOT%{python_sitearch}/*
%endif

# These may be created in non mock systems, but we do not want to package them
# for now
#rm $RPM_BUILD_ROOT%{_mandir}/man1/ad2oLschema.1
rm $RPM_BUILD_ROOT%{_mandir}/man1/oLschema2ldif.1
#rm $RPM_BUILD_ROOT/usr/share/swig/*/talloc.i

rm $RPM_BUILD_ROOT%{_libdir}/pam_smbpass.so

# Remove Files conflicting with regular samba 3.x packages
rm $RPM_BUILD_ROOT%{_libdir}/samba/CHARSET/charset_CP437.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/CHARSET/charset_CP850.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/auth/script.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/idmap/autorid.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/ldb/dirsync.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/libCHARSET3.so
#rm $RPM_BUILD_ROOT%{_libdir}/samba/libLIBCLI_CLDAP.so
#rm $RPM_BUILD_ROOT%{_libdir}/samba/libLIBCLI_LSA3.so
#rm $RPM_BUILD_ROOT%{_libdir}/samba/libLIBCLI_RAW.so
#rm $RPM_BUILD_ROOT%{_libdir}/samba/libLIBCLI_SMB_COMMON.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/libLIBSMB.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/libPOPT_SAMBA3.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/libUTIL_CMDLINE.so
#rm $RPM_BUILD_ROOT%{_libdir}/samba/libUTIL_TDB.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/libaddns.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/libads.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/libadt_tree.so
#rm $RPM_BUILD_ROOT%{_libdir}/samba/libasn1util.so
#rm $RPM_BUILD_ROOT%{_libdir}/samba/libauth_sam_reply.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/libbitmap.so
#rm $RPM_BUILD_ROOT%{_libdir}/samba/libccan.so.0
#rm $RPM_BUILD_ROOT%{_libdir}/samba/libccan.so.0.1-init-1161-g661d41f
#rm $RPM_BUILD_ROOT%{_libdir}/samba/libcli-ldap-common.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/libdbwrap_util.so
#rm $RPM_BUILD_ROOT%{_libdir}/samba/libinterfaces.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/libmemcache.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/libmsrpc3.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/libnamearray.so
#rm $RPM_BUILD_ROOT%{_libdir}/samba/libnpa_tstream.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/libpassdb.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/libsmbd_base.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/libsmbd_conn.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/libsmbd_shim.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/libsmbregistry.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/libstring_init.so
#rm $RPM_BUILD_ROOT%{_libdir}/samba/libtdb_compat.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/libutil_malloc.so
#rm $RPM_BUILD_ROOT%{_libdir}/samba/libutil_reg.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/libutil_sec.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/libutil_str.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/acl_tdb.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/acl_xattr.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/aio_fork.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/audit.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/cap.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/catia.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/crossrename.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/default_quota.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/dirsort.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/expand_msdfs.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/extd_audit.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/fake_perms.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/fileid.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/full_audit.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/linux_xfs_sgid.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/netatalk.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/preopen.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/readahead.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/readonly.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/recycle.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/scannedonly.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/shadow_copy.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/shadow_copy2.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/smb_traffic_analyzer.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/streams_depot.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/streams_xattr.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/syncops.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/time_audit.so
rm $RPM_BUILD_ROOT%{_libdir}/samba/vfs/xattr_tdb.so
rm $RPM_BUILD_ROOT%{_libdir}/winbind_krb5_locator.so
rm $RPM_BUILD_ROOT%{_libdir}/libsmb/libsmbclient.so*
rm $RPM_BUILD_ROOT%{_libdir}/libsmbconf.so*
rm $RPM_BUILD_ROOT%{_libdir}/libsmbsharemodes.so*
rm $RPM_BUILD_ROOT%{_libdir}/libnetapi.so*
rm $RPM_BUILD_ROOT%{_libdir}/libnss_wins.so.2
rm $RPM_BUILD_ROOT%{_includedir}/samba-4.0/libsmbclient.h
rm $RPM_BUILD_ROOT%{_includedir}/samba-4.0/netapi.h
rm $RPM_BUILD_ROOT%{_includedir}/samba-4.0/smb_share_modes.h
rm $RPM_BUILD_ROOT%{_includedir}/samba-4.0/smbconf.h
rm $RPM_BUILD_ROOT%{_sbindir}/nmbd
rm $RPM_BUILD_ROOT%{_sbindir}/smbd
rm $RPM_BUILD_ROOT%{_sbindir}/swat
rm $RPM_BUILD_ROOT%{_sbindir}/winbindd
rm $RPM_BUILD_ROOT%{_bindir}/dbwrap_tool
rm $RPM_BUILD_ROOT%{_bindir}/dbwrap_torture
rm $RPM_BUILD_ROOT%{_bindir}/debug2html
rm $RPM_BUILD_ROOT%{_bindir}/eventlogadm
rm $RPM_BUILD_ROOT%{_bindir}/locktest2
rm $RPM_BUILD_ROOT%{_bindir}/locktest3
rm $RPM_BUILD_ROOT%{_bindir}/log2pcap
rm $RPM_BUILD_ROOT%{_bindir}/masktest3
rm $RPM_BUILD_ROOT%{_bindir}/msgtest
rm $RPM_BUILD_ROOT%{_bindir}/net
rm $RPM_BUILD_ROOT%{_bindir}/nmblookup3
rm $RPM_BUILD_ROOT%{_bindir}/ntlm_auth3
rm $RPM_BUILD_ROOT%{_bindir}/pdbedit
rm $RPM_BUILD_ROOT%{_bindir}/pdbtest
rm $RPM_BUILD_ROOT%{_bindir}/profiles
rm $RPM_BUILD_ROOT%{_bindir}/pthreadpooltest
rm $RPM_BUILD_ROOT%{_bindir}/rpc_open_tcp
rm $RPM_BUILD_ROOT%{_bindir}/rpcclient
rm $RPM_BUILD_ROOT%{_bindir}/sharesec
rm $RPM_BUILD_ROOT%{_bindir}/smbcacls
rm $RPM_BUILD_ROOT%{_bindir}/smbclient3
rm $RPM_BUILD_ROOT%{_bindir}/smbconftort
rm $RPM_BUILD_ROOT%{_bindir}/smbcontrol
rm $RPM_BUILD_ROOT%{_bindir}/smbcquotas
rm $RPM_BUILD_ROOT%{_bindir}/smbfilter
rm $RPM_BUILD_ROOT%{_bindir}/smbget
rm $RPM_BUILD_ROOT%{_bindir}/smbiconv
rm $RPM_BUILD_ROOT%{_bindir}/smbpasswd
rm $RPM_BUILD_ROOT%{_bindir}/smbspool
rm $RPM_BUILD_ROOT%{_bindir}/smbstatus
rm $RPM_BUILD_ROOT%{_bindir}/smbta-util
rm $RPM_BUILD_ROOT%{_bindir}/smbtorture3
rm $RPM_BUILD_ROOT%{_bindir}/smbtree
rm $RPM_BUILD_ROOT%{_bindir}/split_tokens
rm $RPM_BUILD_ROOT%{_bindir}/test_lp_load
rm $RPM_BUILD_ROOT%{_bindir}/timelimit
rm $RPM_BUILD_ROOT%{_bindir}/versiontest
rm $RPM_BUILD_ROOT%{_bindir}/vfstest
rm $RPM_BUILD_ROOT%{_bindir}/vlp
rm $RPM_BUILD_ROOT%{_bindir}/wbinfo3


# This makes the right links, as rpmlint requires that
# the ldconfig-created links be recorded in the RPM.
/sbin/ldconfig -N -n $RPM_BUILD_ROOT%{_libdir}

# Fix up permission on perl install.
%{_fixperms} $RPM_BUILD_ROOT%{perl_vendorlib}

# Fix up permissions for libraries
find $RPM_BUILD_ROOT%{_libdir} -name '*.so*' -type f |xargs chmod +x

# Fix up permissions in source tree, for debuginfo.
find source4/heimdal -type f | xargs chmod -x

%clean
rm -rf $RPM_BUILD_ROOT

%pre
%if %enable_winbind
getent group wbpriv >/dev/null || groupadd -g 88 wbpriv
%endif
exit 0

%post
%if %enable_samba4
/sbin/chkconfig --add %{name}
if [ "$1" -ge "1" ]; then
	/sbin/service %{name} condrestart >/dev/null 2>&1 || :
fi
%endif
exit 0

%preun
%if %enable_samba4
if [ $1 = 0 ] ; then
	/sbin/service %{name} stop >/dev/null 2>&1 || :
	/sbin/chkconfig --del %{name}
fi
%endif
exit 0

%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig


%files
%defattr(-,root,root,-)
%doc COPYING
%if %enable_samba4
%{_sbindir}/provision
%{_sbindir}/samba
%{_sbindir}/upgradeprovision
%{_sbindir}/samba_dnsupdate
%{_sbindir}/samba_spnupdate
%{_bindir}/samba-tool
%{_libdir}/mit_samba.so
%{_mandir}/man8/samba.*
%dir /var/lib/%{name}/sysvol
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%attr(0755,root,root) %{_initrddir}/%{name}
%attr(0700,root,root) %dir /var/log/%{name}
%attr(0700,root,root) %dir /var/log/%{name}/old
%endif

%files libs
%defattr(-,root,root,-)
%doc PFIF.txt
#%dir %{_sysconfdir}/%{name}
#Need to mark this as being owned by Samba, but it is normally created
#by the provision script, which runs best if there is no existing
#smb.conf
#%config(noreplace) %{_sysconfdir}/%{name}/smb.conf
%dir %{_datadir}/samba
%{_datadir}/samba/codepages/*.dat

%{_libdir}/libdcerpc-atsvc.so.*
%{_libdir}/libdcerpc-samr.so.*
%{_libdir}/libdcerpc-server.so.*
%{_libdir}/libdcerpc.so.*
%{_libdir}/libgensec.so.*
%{_libdir}/libndr-krb5pac.so.*
%{_libdir}/libndr.so.*
%{_libdir}/libndr-standard.so.*
%{_libdir}/libpolicy.so.*
%{_libdir}/libregistry.so.*
%{_libdir}/libsamba-hostconfig.so.*
%{_libdir}/libsamba-util.so.*
%{_libdir}/libsamdb.so.*
%{_libdir}/libtorture.so.*

# internal ldb modules
%{_libdir}/samba/ldb/aclread.so
%{_libdir}/samba/ldb/acl.so
%{_libdir}/samba/ldb/anr.so
%{_libdir}/samba/ldb/descriptor.so
%{_libdir}/samba/ldb/extended_dn_in.so
%{_libdir}/samba/ldb/extended_dn_out.so
%{_libdir}/samba/ldb/extended_dn_store.so
%{_libdir}/samba/ldb/ildap.so
%{_libdir}/samba/ldb/instancetype.so
%{_libdir}/samba/ldb/lazy_commit.so
%{_libdir}/samba/ldb/ldbsamba_extensions.so
%{_libdir}/samba/ldb/linked_attributes.so
%{_libdir}/samba/ldb/local_password.so
%{_libdir}/samba/ldb/naming_fsmo.so
%{_libdir}/samba/ldb/new_partition.so
%{_libdir}/samba/ldb/objectclass_attrs.so
%{_libdir}/samba/ldb/objectclass.so
%{_libdir}/samba/ldb/objectguid.so
%{_libdir}/samba/ldb/operational.so
%{_libdir}/samba/ldb/partition.so
%{_libdir}/samba/ldb/password_hash.so
%{_libdir}/samba/ldb/pdc_fsmo.so
%{_libdir}/samba/ldb/ranged_results.so
%{_libdir}/samba/ldb/repl_meta_data.so
%{_libdir}/samba/ldb/resolve_oids.so
%{_libdir}/samba/ldb/rootdse.so
%{_libdir}/samba/ldb/samba3sam.so
%{_libdir}/samba/ldb/samba3sid.so
%{_libdir}/samba/ldb/samba_dsdb.so
%{_libdir}/samba/ldb/samba_secrets.so
%{_libdir}/samba/ldb/samldb.so
%{_libdir}/samba/ldb/schema_data.so
%{_libdir}/samba/ldb/schema_load.so
%{_libdir}/samba/ldb/show_deleted.so
%{_libdir}/samba/ldb/simple_dn.so
%{_libdir}/samba/ldb/simple_ldap_map.so
%{_libdir}/samba/ldb/subtree_delete.so
%{_libdir}/samba/ldb/subtree_rename.so
%{_libdir}/samba/ldb/update_keytab.so
%{_libdir}/samba/ldb/wins_ldb.so

# samba internal libraries
%{_libdir}/samba/gensec/krb5.so
%{_libdir}/samba/libasn1-samba4.so.*
%{_libdir}/samba/libauth4.so
%{_libdir}/samba/libauthkrb5.so
%{_libdir}/samba/libcliauth.so
%{_libdir}/samba/libcli-ldap.so
%{_libdir}/samba/libcli-nbt.so
%{_libdir}/samba/libcluster.so
%{_libdir}/samba/libcmdline-credentials.so
%{_libdir}/samba/libcredentials.so
%{_libdir}/samba/libdb-glue.so
%{_libdir}/samba/libdcerpc-samba4.so
%{_libdir}/samba/libdcerpc-samba.so
%{_libdir}/samba/libdlz_bind9.so
%{_libdir}/samba/libdsdb-module.so
%{_libdir}/samba/liberrors.so
%{_libdir}/samba/libevents.so
%{_libdir}/samba/libgssapi-samba4.so.*
%{_libdir}/samba/libhcrypto-samba4.so.*
%{_libdir}/samba/libhdb-samba4.so.*
%{_libdir}/samba/libheimbase-samba4.so.*
%{_libdir}/samba/libheimntlm-samba4.so.*
%{_libdir}/samba/libhx509-samba4.so.*
%{_libdir}/samba/libkdc-policy.so
%{_libdir}/samba/libkdc-samba4.so.*
%{_libdir}/samba/libkrb5-samba4.so.*
%{_libdir}/samba/libldb-cmdline.so
%{_libdir}/samba/libldbsamba.so
%{_libdir}/samba/libndr-samba4.so
%{_libdir}/samba/libndr-samba.so
%{_libdir}/samba/libnetif.so
%{_libdir}/samba/libntvfs.so
%{_libdir}/samba/libpac.so
%{_libdir}/samba/libprocess_model.so
%{_libdir}/samba/libreplace.so
%{_libdir}/samba/libroken-samba4.so.*
%{_libdir}/samba/librpccommon.so
%{_libdir}/samba/libsamba-net.so
%{_libdir}/samba/libsamba_python.so
%{_libdir}/samba/libsamba-sockets.so
%{_libdir}/samba/libsamdb-common.so
%{_libdir}/samba/libsecurity.so
%{_libdir}/samba/libservice.so
%{_libdir}/samba/libsmbpasswdparser.so
%{_libdir}/samba/libshares.so
%{_libdir}/samba/libsubunit.so
%{_libdir}/samba/libtdb-wrap.so
%{_libdir}/samba/libwinbind-client.so
%{_libdir}/samba/libwind-samba4.so.*
%{_libdir}/samba/libwrap_xattr.so
%{_libdir}/samba/process_model/onefork.so
%{_libdir}/samba/process_model/prefork.so
%{_libdir}/samba/process_model/standard.so
%{_libdir}/samba/service/cldap.so
%{_libdir}/samba/service/dcerpc.so
%{_libdir}/samba/service/dns.so
%{_libdir}/samba/service/dns_update.so
%{_libdir}/samba/service/drepl.so
%{_libdir}/samba/service/kcc.so
%{_libdir}/samba/service/kdc.so
%{_libdir}/samba/service/ldap.so
%{_libdir}/samba/service/nbtd.so
%{_libdir}/samba/service/ntp_signd.so
%{_libdir}/samba/service/samba3_smb.so
%{_libdir}/samba/service/smb.so
%{_libdir}/samba/service/web.so
%{_libdir}/samba/service/winbind.so
%{_libdir}/samba/service/wrepl.so

%{_libdir}/samba/libLIBCLI_CLDAP.so
%{_libdir}/samba/libLIBCLI_LSA3.so
%{_libdir}/samba/libLIBCLI_RAW.so
%{_libdir}/samba/libLIBCLI_SMB_COMMON.so
%{_libdir}/samba/libUTIL_TDB.so
%{_libdir}/samba/libflag_mapping.so
%{_libdir}/samba/libasn1util.so
%{_libdir}/samba/libauth_sam_reply.so
%{_libdir}/samba/libcli-ldap-common.so
%{_libdir}/samba/libflag_mapping.so
%{_libdir}/samba/libinterfaces.so
%{_libdir}/samba/libnpa_tstream.so
%{_libdir}/samba/libtdb_compat.so
%{_libdir}/samba/libutil_reg.so

%if %enable_winbind
%files winbind
%defattr(-,root,root,-)
%{_bindir}/ntlm_auth
%{_bindir}/wbinfo
#%{_libdir}/libwbclient.so.0
%{_libdir}/libnss_winbind.so.2
%{_libdir}/libnss-winbind.inst.so.2
%{_libdir}/pam_winbind.so
%dir /var/run/winbindd
%attr(750,root,wbpriv) %dir /var/lib/%{name}/winbindd_privileged
%{_mandir}/man1/ntlm_auth.*
%endif

%if %enable_python
%files python
%defattr(-,root,root,-)
%{python_sitearch}/*
%endif

%files devel
%defattr(-,root,root,-)
%{_libdir}/libdcerpc.so
%{_libdir}/libdcerpc-samr.so
%{_libdir}/libndr.so
%{_libdir}/libndr-standard.so
%{_libdir}/libsamba-hostconfig.so
%{_libdir}/libsamba-util.so
%{_libdir}/libdcerpc-atsvc.so
%{_libdir}/libdcerpc-server.so
%{_libdir}/libgensec.so
%{_libdir}/libndr-krb5pac.so
%{_libdir}/libpolicy.so
%{_libdir}/libregistry.so
%{_libdir}/libsamdb.so
%{_libdir}/libtorture.so

%{_libdir}/pkgconfig/dcerpc.pc
%{_libdir}/pkgconfig/dcerpc_samr.pc
%{_libdir}/pkgconfig/ndr.pc
%{_libdir}/pkgconfig/ndr_standard.pc
%{_libdir}/pkgconfig/samba-hostconfig.pc
%{_libdir}/pkgconfig/samba-util.pc
%{_libdir}/pkgconfig/dcerpc_atsvc.pc
%{_libdir}/pkgconfig/dcerpc_server.pc
%{_libdir}/pkgconfig/gensec.pc
%{_libdir}/pkgconfig/ndr_krb5pac.pc
%{_libdir}/pkgconfig/policy.pc
%{_libdir}/pkgconfig/registry.pc
%{_libdir}/pkgconfig/samdb.pc
%{_libdir}/pkgconfig/torture.pc

%{_includedir}/samba-4.0/charset.h
%{_includedir}/samba-4.0/core/doserr.h
%{_includedir}/samba-4.0/core/error.h
%{_includedir}/samba-4.0/core/ntstatus.h
%{_includedir}/samba-4.0/core/werror.h
%{_includedir}/samba-4.0/credentials.h
%{_includedir}/samba-4.0/dcerpc_server.h
%{_includedir}/samba-4.0/dcerpc.h
%{_includedir}/samba-4.0/dlinklist.h
%{_includedir}/samba-4.0/domain_credentials.h
%{_includedir}/samba-4.0/gen_ndr/atsvc.h
%{_includedir}/samba-4.0/gen_ndr/auth.h
%{_includedir}/samba-4.0/gen_ndr/dcerpc.h
%{_includedir}/samba-4.0/gen_ndr/epmapper.h
%{_includedir}/samba-4.0/gen_ndr/krb5pac.h
%{_includedir}/samba-4.0/gen_ndr/lsa.h
%{_includedir}/samba-4.0/gen_ndr/mgmt.h
%{_includedir}/samba-4.0/gen_ndr/misc.h
%{_includedir}/samba-4.0/gen_ndr/nbt.h
%{_includedir}/samba-4.0/gen_ndr/ndr_atsvc_c.h
%{_includedir}/samba-4.0/gen_ndr/ndr_atsvc.h
%{_includedir}/samba-4.0/gen_ndr/ndr_dcerpc.h
%{_includedir}/samba-4.0/gen_ndr/ndr_epmapper_c.h
%{_includedir}/samba-4.0/gen_ndr/ndr_epmapper.h
%{_includedir}/samba-4.0/gen_ndr/ndr_krb5pac.h
%{_includedir}/samba-4.0/gen_ndr/ndr_mgmt_c.h
%{_includedir}/samba-4.0/gen_ndr/ndr_mgmt.h
%{_includedir}/samba-4.0/gen_ndr/ndr_misc.h
%{_includedir}/samba-4.0/gen_ndr/ndr_samr_c.h
%{_includedir}/samba-4.0/gen_ndr/ndr_samr.h
%{_includedir}/samba-4.0/gen_ndr/ndr_svcctl_c.h
%{_includedir}/samba-4.0/gen_ndr/ndr_svcctl.h
%{_includedir}/samba-4.0/gen_ndr/netlogon.h
%{_includedir}/samba-4.0/gen_ndr/samr.h
%{_includedir}/samba-4.0/gen_ndr/security.h
%{_includedir}/samba-4.0/gen_ndr/server_id.h
%{_includedir}/samba-4.0/gen_ndr/svcctl.h
%{_includedir}/samba-4.0/gensec.h
%{_includedir}/samba-4.0/ldap_errors.h
%{_includedir}/samba-4.0/ldap_message.h
%{_includedir}/samba-4.0/ldap_ndr.h
%{_includedir}/samba-4.0/ldap-util.h
%{_includedir}/samba-4.0/ldb_wrap.h
%{_includedir}/samba-4.0/ndr.h
%{_includedir}/samba-4.0/param.h
%{_includedir}/samba-4.0/registry.h
%{_includedir}/samba-4.0/roles.h
%{_includedir}/samba-4.0/samba/popt.h
%{_includedir}/samba-4.0/samba/session.h
%{_includedir}/samba-4.0/samba/version.h
%{_includedir}/samba-4.0/share.h
%{_includedir}/samba-4.0/tdr.h
%{_includedir}/samba-4.0/torture.h
%{_includedir}/samba-4.0/tsocket.h
%{_includedir}/samba-4.0/tsocket_internal.h
%{_includedir}/samba-4.0/util/attr.h
%{_includedir}/samba-4.0/util/byteorder.h
%{_includedir}/samba-4.0/util/data_blob.h
%{_includedir}/samba-4.0/util/debug.h
%{_includedir}/samba-4.0/util/memory.h
%{_includedir}/samba-4.0/util/safe_string.h
%{_includedir}/samba-4.0/util/string_wrappers.h
%{_includedir}/samba-4.0/util/talloc_stack.h
%{_includedir}/samba-4.0/util/tevent_ntstatus.h
%{_includedir}/samba-4.0/util/tevent_unix.h
%{_includedir}/samba-4.0/util/tevent_werror.h
%{_includedir}/samba-4.0/util/time.h
%{_includedir}/samba-4.0/util/xfile.h
%{_includedir}/samba-4.0/util.h
%{_includedir}/samba-4.0/util_ldb.h
%{_includedir}/samba-4.0/rpc_common.h
%{_includedir}/samba-4.0/ndr/ndr_svcctl.h

%if %enable_winbind
#%{_libdir}/libwbclient.so
%{_includedir}/samba-4.0/wbclient.h
%endif

%files pidl
%defattr(-,root,root,-)
%{perl_vendorlib}/*
%{_mandir}/man1/pidl*
%{_mandir}/man3/Parse*
%attr(755,root,root) %{_bindir}/pidl

%if %enable_client
%files client
%defattr(-,root,root,-)
%{_bindir}/nmblookup
%{_bindir}/smbclient
%{_bindir}/cifsdd
%{_mandir}/man1/nmblookup.*
%endif

%if %enable_common
%files common
%defattr(-,root,root,-)
%{_bindir}/testparm
%{_bindir}/regdiff
%{_bindir}/regpatch
%{_bindir}/regshell
%{_bindir}/regtree
%{_mandir}/man1/regdiff.*
%{_mandir}/man1/regpatch.*
%{_mandir}/man1/regshell.*
%{_mandir}/man1/regtree.*

%dir /var/lib/%{name}
%attr(700,root,root) %dir /var/lib/%{name}/private
# We don't want to put a smb.conf in by default, provision should create it
#%config(noreplace) %{_sysconfdir}/%{name}/smb.conf
%endif

%changelog
* Thu Aug 29 2011 Milan Crha <mcrha@redhat.com> - 4.0.0-37.alpha16
- Make 4.0.0-37.alpha16 release

* Fri Aug 26 2011 Stephen Gallagher <sgallagh@redhat.com> - 4.0.0-36.alpha16.1
- Rebuilding against libtalloc 2.0.6 (fixes a dep change in pytalloc)

* Thu Aug 11 2011 Milan Crha <mcrha@redhat.com> - 4.0.0-36.alpha16
- Keep more libraries in samba4-libs and make conflicting as builtin.

* Tue Aug  2 2011 Simo Sorce <ssorce@redhat.com> - 4.0.0-35.alpha16
- Rebase to new upstream release.
  This release is needed to build newer openchange libraries.

* Sun Jun 19 2011 Marcela Mašláňová <mmaslano@redhat.com> - 4.0.0-34.alpha15GITa6a722b.1
- Perl mass rebuild

* Thu Mar 17 2011 Simo Sorce <ssorce@redhat.com> - 4.0.0-34.alpha15GITa6a722b
- New snapshot with fixes for openchange builds
- Additional patches to fix public headers install
- Move public function in public library

* Thu Mar 10 2011 Simo Sorce <ssorce@redhat.com> - 4.0.0-33.alpha15
- Remove unneded dependency.
  We need to do this instead of simply adding libwbclient as this library would
  conflict with the basic samba (3.x) packages, and libwbclient makes sense
  only when coupled with the corresponding winbind daemon which we do not build
  in samba4.

* Fri Mar  4 2011 Simo Sorce <ssorce@redhat.com> - 4.0.0-32.alpha15
- Try to fix provides issue to to upstream libraries build bug

* Fri Feb 25 2011 Simo Sorce <ssorce@redhat.com> - 4.0.0-31.alpha15
- Fix librraiues permissions to correctly generate dependencies

* Wed Feb 23 2011 Simo Sorce <ssorce@redhat.com> - 4.0.0-30.alpha15
- Some more changes in private libs.

* Wed Feb 23 2011 Simo Sorce <ssorce@redhat.com> - 4.0.0-29.alpha15
- Fix last minute changes in private libs.

* Wed Feb 23 2011 Simo Sorce <ssorce@redhat.com> - 4.0.0-28.alpha15
- Newer snapshot that fixes an upstream build issue.

* Tue Feb 22 2011 Simo Sorce <ssorce@redhat.com> - 4.0.0-27.alpha15
- Build a snapshot of the master tree pre-alpha15 to test a koji build.
  Also allows testing new open change builds openchange new bits, so we are
  ready to release to F15 as soon as alpha15 is released.

* Mon Feb 21 2011 Simo Sorce <ssorce@redhat.com> - 4.0.0-26.alpha15
- Prepare for Alpha 15 release
- Provide all libraries

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.0.0-25.alpha11.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sun Aug 01 2010 Matthew Barnes <mbarnes@redhat.com> - 4.0.0-25.alpha11
- Fix typo (RH bug #619946).

* Mon Jun 28 2010 Ralf Corsépius <corsepiu@fedoraproject.org> - 4.0.0-24.alpha11
- Revert changes to %%Release, use %%main_release instead.
- Rebuild for perl-5.12.x.

* Mon Jun 28 2010 Ralf Corsépius <corsepiu@fedoraproject.org> - 4.0.0-23.alpha11.2
- Once again rebuild for perl-5.12.x.

* Wed Jun 02 2010 Marcela Maslanova <mmaslano@redhat.com> - 4.0.0-23.alpha11.1
- Mass rebuild with perl-5.12.0

* Wed Feb 24 2010 Stephen Gallagher <sgallagh@redhat.com> - 4.0.0-23.alpha11
- Rebuild against newer libtevent

* Sun Jan 24 2010 Matthew Barnes <mbarnes@redhat.com> - 4.0.0-22.alpha11
- Upgrade to alpha11

* Fri Jan 08 2010 Matthew Barnes <mbarnes@redhat.com> - 4.0.0-21.alpha10
- Bump ldb_version to 0.9.10.

* Fri Jan 08 2010 Matthew Barnes <mbarnes@redhat.com> - 4.0.0-20.alpha10
- Only install new command-line utilities if enable_samba4 is non-zero.

* Wed Jan 06 2010 Matthew Barnes <mbarnes@redhat.com> - 4.0.0-19.alpha10
- Upgrade to alpha10

* Thu Sep 17 2009 Simo Sorce <ssorce@redhat.com> - 4.0.0-18.1.alpha8_git20090916
- Need docbook stuff to build man pages

* Thu Sep 17 2009 Simo Sorce <ssorce@redhat.com> - 4.0.0-18.alpha8_git20090916
- Fix broken dependencies

* Wed Sep 16 2009 Simo Sorce <ssorce@redhat.com> - 4.0.0-17.alpha8_git20090916
- Upgrade to alpha8-git20090916

* Wed Sep 16 2009 Simo Sorce <ssorce@redhat.com> - 4.0.0-16.alpha7
- Stop building libtevent, it is now an external package

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.0.0-15.2alpha7.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri May 22 2009 Simo Sorce <ssorce@redhat.com> - 4.0.0-15.2alpha7
- Fix dependency

* Sat May 09 2009  Simo Sorce <ssorce@redhat.com> - 4.0.0-15.1alpha7
- Don't build talloc and tdb, they are now separate packages

* Mon Apr 06 2009 Matthew Barnes <mbarnes@redhat.com> - 4.0.0-14alpha7
- Fix a build issue in samba4-common (RH bug #494243).

* Wed Mar 25 2009 Simo Sorce <ssorce@redhat.com> - 4.0.0-13alpha7
- rebuild with correct CFLAGS (also fixes debuginfo)

* Tue Mar 10 2009 Simo Sorce <ssorce@redhat.com> - 4.0.0-12alpha7
- Second part of fix for the ldb segfault problem from upstream

* Mon Mar 09 2009 Simo Sorce <ssorce@redhat.com> - 4.0.0-11alpha7
- Add upstream patch to fix a problem within ldb

* Sun Mar 08 2009 Matthew Barnes <mbarnes@redhat.com> - 4.0.0-10alpha7
- Remove ldb.pc from samba4-devel (RH bug #489186).

* Wed Mar  4 2009 Simo Sorce <ssorce@redhat.com> - 4.0.0-9alpha7
- Make talloc,tdb,tevent,ldb easy to exclude using defines
- Fix package for non-mock "dirty" systems by deleting additional
  files we are not interested in atm

* Wed Mar  4 2009 Simo Sorce <ssorce@redhat.com> - 4.0.0-8alpha7
- Fix typo in Requires

* Mon Mar  2 2009 Simo Sorce <ssorce@redhat.com> - 4.0.0-7alpha7
- Compile and have separate packages for additional samba libraries
  Package in their own packages: talloc, tdb, tevent, ldb

* Fri Feb 27 2009 Matthew Barnes <mbarnes@redhat.com> - 4.0.0-4.alpha7
- Update to 4.0.0alpha7

* Wed Feb 25 2009 Matthew Barnes <mbarnes@redhat.com> - 4.0.0-3.alpha6
- Formal package review cleanups.

* Mon Feb 23 2009 Matthew Barnes <mbarnes@redhat.com> - 4.0.0-2.alpha6
- Disable subpackages not needed by OpenChange.
- Incorporate package review feedback.

* Mon Jan 19 2009 Matthew Barnes <mbarnes@redhat.com> - 4.0.0-1.alpha6
- Update to 4.0.0alpha6

* Wed Dec 17 2008 Matthew Barnes <mbarnes@redhat.com> - 4.0.0-0.8.alpha6.GIT.3508a66
- Fix another file conflict: smbstatus

* Fri Dec 12 2008 Matthew Barnes <mbarnes@redhat.com> - 4.0.0-0.7.alpha6.GIT.3508a66
- Disable the winbind subpackage because it conflicts with samba-winbind
  and isn't needed to support OpenChange.

* Fri Dec 12 2008 Matthew Barnes <mbarnes@redhat.com> - 4.0.0-0.6.alpha6.GIT.3508a66
- Update to the GIT revision OpenChange is now requiring.

* Fri Aug 29 2008 Andrew Bartlett <abartlet@samba.org> - 0:4.0.0-0.5.alpha5.fc10
- Fix licence tag (the binaries are built into a GPLv3 whole, so the BSD licence need not be mentioned)

* Fri Jul 25 2008 Andrew Bartlett <abartlet@samba.org> - 0:4.0.0-0.4.alpha5.fc10
- Remove talloc and tdb dependency (per https://bugzilla.redhat.com/show_bug.cgi?id=453083)
- Fix deps on chkconfig and service to main pkg (not -common) 
  (per https://bugzilla.redhat.com/show_bug.cgi?id=453083)

* Mon Jul 21 2008 Brad Hards <bradh@frogmouth.ent> - 0:4.0.0-0.3.alpha5.fc10
- Use --sysconfdir instead of --with-configdir
- Add patch for C++ header compatibility

* Mon Jun 30 2008 Andrew Bartlett <abartlet@samba.org> - 0:4.0.0-0.2.alpha5.fc9
- Update per review feedback
- Update for alpha5

* Thu Jun 26 2008 Andrew Bartlett <abartlet@samba.org> - 0:4.0.0-0.1.alpha4.fc9
- Rework Fedora's Samba 3.2.0-1.rc2.16 spec file for Samba4
